@@ -156,6 +156,14 @@ class AppSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#close)
+        """
+
     def create_api_cache(
         self,
         *,
@@ -191,12 +199,12 @@ class AppSyncClient(BaseClient):
         type: DataSourceTypeType,
         description: str = ...,
         serviceRoleArn: str = ...,
-        dynamodbConfig: "DynamodbDataSourceConfigTypeDef" = ...,
-        lambdaConfig: "LambdaDataSourceConfigTypeDef" = ...,
-        elasticsearchConfig: "ElasticsearchDataSourceConfigTypeDef" = ...,
-        openSearchServiceConfig: "OpenSearchServiceDataSourceConfigTypeDef" = ...,
-        httpConfig: "HttpDataSourceConfigTypeDef" = ...,
-        relationalDatabaseConfig: "RelationalDatabaseDataSourceConfigTypeDef" = ...
+        dynamodbConfig: DynamodbDataSourceConfigTypeDef = ...,
+        lambdaConfig: LambdaDataSourceConfigTypeDef = ...,
+        elasticsearchConfig: ElasticsearchDataSourceConfigTypeDef = ...,
+        openSearchServiceConfig: OpenSearchServiceDataSourceConfigTypeDef = ...,
+        httpConfig: HttpDataSourceConfigTypeDef = ...,
+        relationalDatabaseConfig: RelationalDatabaseDataSourceConfigTypeDef = ...
     ) -> CreateDataSourceResponseTypeDef:
         """
         Creates a `DataSource` object.
@@ -225,7 +233,7 @@ class AppSyncClient(BaseClient):
         description: str = ...,
         requestMappingTemplate: str = ...,
         responseMappingTemplate: str = ...,
-        syncConfig: "SyncConfigTypeDef" = ...,
+        syncConfig: SyncConfigTypeDef = ...,
         maxBatchSize: int = ...
     ) -> CreateFunctionResponseTypeDef:
         """
@@ -240,15 +248,13 @@ class AppSyncClient(BaseClient):
         *,
         name: str,
         authenticationType: AuthenticationTypeType,
-        logConfig: "LogConfigTypeDef" = ...,
-        userPoolConfig: "UserPoolConfigTypeDef" = ...,
-        openIDConnectConfig: "OpenIDConnectConfigTypeDef" = ...,
+        logConfig: LogConfigTypeDef = ...,
+        userPoolConfig: UserPoolConfigTypeDef = ...,
+        openIDConnectConfig: OpenIDConnectConfigTypeDef = ...,
         tags: Mapping[str, str] = ...,
-        additionalAuthenticationProviders: Sequence[
-            "AdditionalAuthenticationProviderTypeDef"
-        ] = ...,
+        additionalAuthenticationProviders: Sequence[AdditionalAuthenticationProviderTypeDef] = ...,
         xrayEnabled: bool = ...,
-        lambdaAuthorizerConfig: "LambdaAuthorizerConfigTypeDef" = ...
+        lambdaAuthorizerConfig: LambdaAuthorizerConfigTypeDef = ...
     ) -> CreateGraphqlApiResponseTypeDef:
         """
         Creates a `GraphqlApi` object.
@@ -267,9 +273,9 @@ class AppSyncClient(BaseClient):
         requestMappingTemplate: str = ...,
         responseMappingTemplate: str = ...,
         kind: ResolverKindType = ...,
-        pipelineConfig: "PipelineConfigTypeDef" = ...,
-        syncConfig: "SyncConfigTypeDef" = ...,
-        cachingConfig: "CachingConfigTypeDef" = ...,
+        pipelineConfig: PipelineConfigTypeDef = ...,
+        syncConfig: SyncConfigTypeDef = ...,
+        cachingConfig: CachingConfigTypeDef = ...,
         maxBatchSize: int = ...
     ) -> CreateResolverResponseTypeDef:
         """
@@ -621,12 +627,12 @@ class AppSyncClient(BaseClient):
         type: DataSourceTypeType,
         description: str = ...,
         serviceRoleArn: str = ...,
-        dynamodbConfig: "DynamodbDataSourceConfigTypeDef" = ...,
-        lambdaConfig: "LambdaDataSourceConfigTypeDef" = ...,
-        elasticsearchConfig: "ElasticsearchDataSourceConfigTypeDef" = ...,
-        openSearchServiceConfig: "OpenSearchServiceDataSourceConfigTypeDef" = ...,
-        httpConfig: "HttpDataSourceConfigTypeDef" = ...,
-        relationalDatabaseConfig: "RelationalDatabaseDataSourceConfigTypeDef" = ...
+        dynamodbConfig: DynamodbDataSourceConfigTypeDef = ...,
+        lambdaConfig: LambdaDataSourceConfigTypeDef = ...,
+        elasticsearchConfig: ElasticsearchDataSourceConfigTypeDef = ...,
+        openSearchServiceConfig: OpenSearchServiceDataSourceConfigTypeDef = ...,
+        httpConfig: HttpDataSourceConfigTypeDef = ...,
+        relationalDatabaseConfig: RelationalDatabaseDataSourceConfigTypeDef = ...
     ) -> UpdateDataSourceResponseTypeDef:
         """
         Updates a `DataSource` object.
@@ -656,7 +662,7 @@ class AppSyncClient(BaseClient):
         description: str = ...,
         requestMappingTemplate: str = ...,
         responseMappingTemplate: str = ...,
-        syncConfig: "SyncConfigTypeDef" = ...,
+        syncConfig: SyncConfigTypeDef = ...,
         maxBatchSize: int = ...
     ) -> UpdateFunctionResponseTypeDef:
         """
@@ -671,15 +677,13 @@ class AppSyncClient(BaseClient):
         *,
         apiId: str,
         name: str,
-        logConfig: "LogConfigTypeDef" = ...,
+        logConfig: LogConfigTypeDef = ...,
         authenticationType: AuthenticationTypeType = ...,
-        userPoolConfig: "UserPoolConfigTypeDef" = ...,
-        openIDConnectConfig: "OpenIDConnectConfigTypeDef" = ...,
-        additionalAuthenticationProviders: Sequence[
-            "AdditionalAuthenticationProviderTypeDef"
-        ] = ...,
+        userPoolConfig: UserPoolConfigTypeDef = ...,
+        openIDConnectConfig: OpenIDConnectConfigTypeDef = ...,
+        additionalAuthenticationProviders: Sequence[AdditionalAuthenticationProviderTypeDef] = ...,
         xrayEnabled: bool = ...,
-        lambdaAuthorizerConfig: "LambdaAuthorizerConfigTypeDef" = ...
+        lambdaAuthorizerConfig: LambdaAuthorizerConfigTypeDef = ...
     ) -> UpdateGraphqlApiResponseTypeDef:
         """
         Updates a `GraphqlApi` object.
@@ -698,9 +702,9 @@ class AppSyncClient(BaseClient):
         requestMappingTemplate: str = ...,
         responseMappingTemplate: str = ...,
         kind: ResolverKindType = ...,
-        pipelineConfig: "PipelineConfigTypeDef" = ...,
-        syncConfig: "SyncConfigTypeDef" = ...,
-        cachingConfig: "CachingConfigTypeDef" = ...,
+        pipelineConfig: PipelineConfigTypeDef = ...,
+        syncConfig: SyncConfigTypeDef = ...,
+        cachingConfig: CachingConfigTypeDef = ...,
         maxBatchSize: int = ...
     ) -> UpdateResolverResponseTypeDef:
         """
